import logging
from friendlyurls.models import *
from django.core.urlresolvers import resolve
from django.http import HttpResponseForbidden, HttpResponse, Http404
from django.conf import settings

log = logging.getLogger(__name__)

def resolve_friendly_url(request):

  # Check to see if the abort attribute exists on request. If it does it means
  # it was set previously from a resolve_friendly_url call.
  if( getattr(request, 'abort', None) != None ):
    log.error("Error returning view for friendlyurl. Please check that %s is a valid url." % request.previous_url)
    raise Http404

  # Check to see if there is a redirect for this URL
  try:
    # Make sure we only try to resolve vanity URLs a single time
    request.abort = True

    start_path, sep, remaining_path = request.path.strip('/').partition('/')
    log.debug("Lookup path [%s] | [%s]" % (start_path, remaining_path) )

    if( settings.FRIENDLYURLS_IGNORE_CASE == True ):
      redirection = UrlMapping.objects.get(friendly_path__iexact = start_path)
    else:
      redirection = UrlMapping.objects.get(friendly_path = start_path)

    log.debug("URL mapping found. Returning get_absolute_url() on %s" % redirection.content_object)

    # Absolute URL for object
    obj_absolute_url = redirection.content_object.get_absolute_url()
    request.previous_url = obj_absolute_url

    if( remaining_path != '' ):
      view, args, kwargs = resolve("%s/%s" % (obj_absolute_url, remaining_path))
    else:
      view, args, kwargs = resolve(obj_absolute_url)

    kwargs['request'] = request
    return view(*args, **kwargs)

  except UrlMapping.DoesNotExist:
    log.error("No URL mapping exists for: %s" % request.path)
    raise Http404



from django.contrib import admin
from friendlyurls.models import *

class UrlMappingAdmin(admin.ModelAdmin):
  list_display = ('friendly_path', 'resolved_url', 'content_type', 'object')
admin.site.register(UrlMapping, UrlMappingAdmin)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
try:
    from setuptools import setup
except ImportError:
    from ez_setup import use_setuptools
    use_setuptools()
    from setuptools import setup

setup(
    name='django_friendlyurls',
    version='0.1.1',
    description='Use friendly urls with Django.',
    author='Jeff Tchang',
    author_email='jeff.tchang@gmail.com',
    url='http://github.com/tachang/django_friendlyurls/',
    zip_safe = False,
    long_description=open('README.rst', 'r').read(),
    packages=[
        'friendlyurls',
    ],
    package_data={
        'friendlyurls': ['templates/friendlyurls/*'],
    },
    requires=[
    ],
    install_requires=[
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Utilities'
    ],
)



from django.contrib.auth.models import User
from django.db import models
from django.contrib.contenttypes import generic
from django.contrib.contenttypes.models import ContentType

class UrlMapping(models.Model):
  friendly_path = models.CharField(max_length=512, db_index=True, unique=True)
  content_type = models.ForeignKey(ContentType)
  object_id = models.CharField(max_length=256)
  content_object = generic.GenericForeignKey()
  created = models.DateTimeField(auto_now=True, blank=True)

  def __unicode__(self):
    return "%s" % (self.friendly_path)

  def resolved_url(self):
    """Call get_absolute_url() on the content_object and return the url.
    """
    return self.content_object.get_absolute_url()

  def object(self):
    return str(self.content_object)
